==> python_helper-0.3.54.tar.gz: python_helper-0.3.54/Tests.py <==
from python_helper import TestHelper
TestHelper.run(__file__, inspectGlobals=False)
# TestHelper.run(
#     __file__,
#     runOnly = [
#         # 'ReflectionHelperTest.instanciateItWithNoArgsConstructor_withSuccess',
#         'ReflectionHelperTest.getAttributeOrMethodByNamePath'
#     ]
# )
# TestHelper.run(__file__,
#     testStatus = True,
#     logStatus = True,
#     logResult = True,
#     inspectGlobals=False
# )
# TestHelper.run(
#     __file__,
#     runOnly = [
#         # 'ObjectHelperTest.equal_whenListOfDictionaries',
#         'ObjectHelperTest.equal_whenSets'
#     ]
# )
# TestHelper.run(
#     __file__,
#     runOnly = [
#         'SettingHelperTest.updateActiveEnvironment_withSuccess',
#         'SettingHelperTest.mustReadSettingFile',
#         'SettingHelperTest.mustNotReadSettingFile',
#         'SettingHelperTest.mustPrintSettingTree',
#         'SettingHelperTest.mustHandleSettingValueInFallbackSettingTree',
#         'SettingHelperTest.mustHandleSettingValueInFallbackSettingTree_whenFallbackSettingFilePathIsPassedInsted',
#         'SettingHelperTest.getSettingTree_whenIsSettingKeyActuallyContainsSettingKey',
#         'SettingHelperTest.getSettingTree_fallbackPriority',
#         'SettingHelperTest.getSettingTree_otherApplication',
#         'SettingHelperTest.getSettingTree_whenThereAreNoneValuesAllOverThePlace',
#         'SettingHelperTest.getBooleanSetting'
#     ],
#     # testStatus = False,
#     # logStatus = False,
#     # logResult = True,
#     # inspectGlobals = False
# )
# TestHelper.run(
#     __file__,
#     times = 2,
#     testStatus = False,
#     logStatus = True,
#     logResult = True,
#     inspectGlobals = True
# )
# TestHelper.run(
#     __file__,
#     # times = 10,
#     runOnly = [
#         'LogHelperTest.mustLogWithColors',
#         'LogHelperTest.mustLogWithoutColors',
#         'LogHelperTest.mustLogWithoutColorsAsWell',
#         'LogHelperTest.mustLogEnvironmentSettings',
#         'LogHelperTest.mustLogPretyPythonWithoutColors',
#         'LogHelperTest.mustLogPretyPythonWithColors',
#         'LogHelperTest.mustLogPretyJsonWithColors',
#         'LogHelperTest.mustPrintMessageLog_withColors'
#     ],
#     testStatus = False,
#     logStatus = False,
#     logResult = False,
#     inspectGlobals = False
# )
# TestHelper.run(
#     __file__,
#     times = 100,
#     runOnly = [
#         'StringHelperTest.prettyJson_withSucces'
#     ],
#     testStatus = False,
#     logStatus = False,
#     logResult = True,
#     inspectGlobals = False
# )
# TestHelper.run(
#     __file__,
#     times = 100,
#     runOnly = [
#         'StringHelperTest.prettyPython_withSucces'
#     ],
#     testStatus = False,
#     logStatus = False,
#     logResult = True,
#     inspectGlobals = False
# )
# TestHelper.run(
#     __file__,
#     times = 10,
#     testStatus = False,
#     logStatus = False,
#     logResult = True,
#     inspectGlobals = False
# )
# TestHelper.run(
#     __file__,
#     times = 1,
#     runOnly = [
#         'StringHelperTest.prettifyPerformance'
#     ],
#     testStatus = False,
#     logStatus = False,
#     logResult = True,
#     inspectGlobals = False
# )
# TestHelper.run(
#     __file__,
#     times = 1,
#     runOnly = [
#         'ModuleImportsTest.allImportedSuccesfuly'
#     ],
#     testStatus = False,
#     logStatus = False,
#     logResult = False,
#     inspectGlobals = False
# )
# TestHelper.run(
#     __file__,
#     times = 1,
#     runOnly = [
#         'SettingHelperTest.getSettingTree_fallbackPriority'
#     ],
#     settingStatus = False,
#     testStatus = False,
#     logStatus = False,
#     logResult = False,
#     inspectGlobals = False
# )
# TestHelper.run(
#     __file__,
#     times = 1,
#     runOnly = [
#         'MethodAnnotationTest.Function_withSuccess'
#     ],
#     testStatus = False,
#     logStatus = False,
#     logResult = False,
#     inspectGlobals = False
# )
# TestHelper.run(
#     __file__,
#     times = 1,
#     runOnly = [
#         'LogHelperTest.mustLogWithColors'
#     ],
#     testStatus = False,
#     logStatus = False,
#     logResult = False,
#     inspectGlobals = True
# )
# TestHelper.run(
#     __file__,
#     runOnly = [
#         'ReflectionHelperTest.getName_manyCases'
#     ]
# )
# TestHelper.run(
#     __file__,
#     runOnly = [
#         'EnvironmentHelperTest.osIdentifierTest'
#     ]
# )
# TestHelper.run(
#     __file__,
#     runOnly = [
#         'SettingHelperTest.getSettingTree_whenThereAreNoneValuesAllOverThePlace'
#     ]
# )

==> python_helper-0.3.57.tar.gz: python_helper-0.3.57/Tests.py <==
from python_helper import TestHelper
TestHelper.run(__file__, inspectGlobals=False)
# TestHelper.run(
#     __file__,
#     runOnly = [
#         # 'ReflectionHelperTest.instanciateItWithNoArgsConstructor_withSuccess',
#         'ReflectionHelperTest.getAttributeOrMethodByNamePath'
#     ]
# )
# TestHelper.run(__file__,
#     testStatus = True,
#     logStatus = True,
#     logResult = True,
#     inspectGlobals=False
# )
# TestHelper.run(
#     __file__,
#     runOnly = [
#         # 'ObjectHelperTest.equal_whenListOfDictionaries',
#         'ObjectHelperTest.equal_whenSets'
#     ]
# )
# TestHelper.run(
#     __file__,
#     runOnly = [
#         # 'SettingHelperTest.mustHandleLateValue',
#         # 'SettingHelperTest.updateActiveEnvironment_withSuccess',
#         # 'SettingHelperTest.mustReadSettingFile',
#         # 'SettingHelperTest.mustNotReadSettingFile',
#         # 'SettingHelperTest.mustPrintSettingTree',
#         # 'SettingHelperTest.mustHandleSettingValueInFallbackSettingTree',
#         # 'SettingHelperTest.mustHandleSettingValueInFallbackSettingTree_whenFallbackSettingFilePathIsPassedInsted',
#         # 'SettingHelperTest.getSettingTree_whenIsSettingKeyActuallyContainsSettingKey',
#         # 'SettingHelperTest.getSettingTree_fallbackPriority',
#         # 'SettingHelperTest.getSettingTree_otherApplication',
#         # 'SettingHelperTest.getSettingTree_whenThereAreNoneValuesAllOverThePlace',
#         # 'SettingHelperTest.getBooleanSetting'
#     ],
#     # testStatus = False,
#     # logStatus = False,
#     # logResult = True,
#     # inspectGlobals = False
# )
# TestHelper.run(
#     __file__,
#     times = 2,
#     testStatus = False,
#     logStatus = True,
#     logResult = True,
#     inspectGlobals = True
# )
# TestHelper.run(
#     __file__,
#     # times = 10,
#     runOnly = [
#         'LogHelperTest.mustLogWithColors',
#         'LogHelperTest.mustLogWithoutColors',
#         'LogHelperTest.mustLogWithoutColorsAsWell',
#         'LogHelperTest.mustLogEnvironmentSettings',
#         'LogHelperTest.mustLogPretyPythonWithoutColors',
#         'LogHelperTest.mustLogPretyPythonWithColors',
#         'LogHelperTest.mustLogPretyJsonWithColors',
#         'LogHelperTest.mustPrintMessageLog_withColors'
#     ],
#     testStatus = False,
#     logStatus = False,
#     logResult = False,
#     inspectGlobals = False
# )
# TestHelper.run(
#     __file__,
#     times = 100,
#     runOnly = [
#         'StringHelperTest.prettyJson_withSucces'
#     ],
#     testStatus = False,
#     logStatus = False,
#     logResult = True,
#     inspectGlobals = False
# )
# TestHelper.run(
#     __file__,
#     times = 100,
#     runOnly = [
#         'StringHelperTest.prettyPython_withSucces'
#     ],
#     testStatus = False,
#     logStatus = False,
#     logResult = True,
#     inspectGlobals = False
# )
# TestHelper.run(
#     __file__,
#     times = 10,
#     testStatus = False,
#     logStatus = False,
#     logResult = True,
#     inspectGlobals = False
# )
# TestHelper.run(
#     __file__,
#     times = 1,
#     runOnly = [
#         'StringHelperTest.prettifyPerformance'
#     ],
#     testStatus = False,
#     logStatus = False,
#     logResult = True,
#     inspectGlobals = False
# )
# TestHelper.run(
#     __file__,
#     times = 1,
#     runOnly = [
#         'ModuleImportsTest.allImportedSuccesfuly'
#     ],
#     testStatus = False,
#     logStatus = False,
#     logResult = False,
#     inspectGlobals = False
# )
# TestHelper.run(
#     __file__,
#     times = 1,
#     runOnly = [
#         'SettingHelperTest.getSettingTree_fallbackPriority'
#     ],
#     settingStatus = False,
#     testStatus = False,
#     logStatus = False,
#     logResult = False,
#     inspectGlobals = False
# )
# TestHelper.run(
#     __file__,
#     times = 1,
#     runOnly = [
#         'MethodAnnotationTest.Function_withSuccess'
#     ],
#     testStatus = False,
#     logStatus = False,
#     logResult = False,
#     inspectGlobals = False
# )
# TestHelper.run(
#     __file__,
#     times = 1,
#     runOnly = [
#         'LogHelperTest.mustLogWithColors'
#     ],
#     testStatus = False,
#     logStatus = False,
#     logResult = False,
#     inspectGlobals = True
# )
# TestHelper.run(
#     __file__,
#     runOnly = [
#         'ReflectionHelperTest.getName_manyCases'
#     ]
# )
# TestHelper.run(
#     __file__,
#     runOnly = [
#         'EnvironmentHelperTest.osIdentifierTest'
#     ]
# )
# TestHelper.run(
#     __file__,
#     runOnly = [
#         'SettingHelperTest.getSettingTree_whenThereAreNoneValuesAllOverThePlace'
#     ]
# )
